青蛇 (豆瓣)
Description: 青蛇电影简介和剧情介绍,青蛇影评、图片、预告片、影讯、论坛、在线购票
Keywords: 青蛇,青蛇,青蛇影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.216豆瓣电影Top250

# 青蛇 (1993)

导演: 徐克
编剧: 李碧华 / 徐克
主演: 张曼玉 / 王祖贤 / 赵文卓 / 吴兴国 / 马精武 / 田丰 / 刘洵
类型: 剧情 / 爱情 / 奇幻 / 古装
制片国家/地区: 中国香港 / 中国大陆
语言: 粤语 / 汉语普通话
上映日期: 1993-11-04(中国香港)
片长: 99分钟
又名: Green Snake
IMDb: tt0106559
豆瓣评分
引用
8.6
497344人评价
5星
44.5%
4星
42.7%
3星
11.9%
2星
0.8%
1星
0.1%
好于 97% 奇幻片
好于 98% 爱情片
想看 看过
评价:
推荐

## 青蛇的剧情简介 · · · · · ·

南宋是一个人妖难分的时期，法海和尚（赵文卓 饰）到处收服妖精，也扰乱了在西湖底修炼的白青二蛇。青（张曼玉 饰）曾获白（王祖贤 饰）相救，二者便以姐妹相称。姐妹俩受惑佯装成人生活在民间，白更嫁于老实书生许仙，青也同时看上了许仙，便常常以媚态勾引许仙，无奈许仙只深爱白一个。白开设了药店，以为可以自此过上安定的生活，可许仙却受不了青的百般挑逗，更发现了青白二蛇的真实身份，可他却不舍得离开家中的天姿国色。法海得知了青白二蛇的下落，更抓走了许仙。原来白为了爱情放弃修成正果，更怀有了身孕。为了救回丈夫，二蛇与法海展开了搏斗…… ©豆瓣

## 青蛇的演职员 · · · · · · ( 全部 25 )

- 徐克 导演
- 张曼玉 饰 小青
- 王祖贤 饰 白素贞
- 赵文卓 饰 法海
- 吴兴国 饰 许仙
- 马精武 饰 盲道士全真子

## 青蛇的视频和图片 · · · · · · ( 视频评论1 · 添加 | 图片1410 · 添加 )

## 青蛇的获奖情况 · · · · · · ( 全部 )

- 第13届香港电影金像奖
- 最佳美术指导(提名)
- 雷楚雄

- 第13届香港电影金像奖
- 最佳服装造型设计(提名)
- 张叔平 / 吴宝玲

- 第13届香港电影金像奖
- 最佳原创电影音乐(提名)
- 黄霑 / 雷颂德

## 喜欢这部电影的人也喜欢 · · · · · ·

  倩女幽魂

  甜蜜蜜

  罗马假日

  花样年华

  胭脂扣

  重庆森林

  加勒比海盗

  泰坦尼克号

  东邪西毒

  大话西游之月光宝盒

我要写短评

## 青蛇的短评 · · · · · · ( 全部 94315 条 )

热门 / 最新 / 好友

### 6076 有用 伊豆 看过 2008-10-14 11:25:26

当时很不能接受的是，许仙竟然和小青有暧昧。不过长大之后再回想，男人，可不就是这样的么。

### 2891 有用 光年‖影视歌三栖民工 看过 2008-10-31 23:54:10

作为一个性格被阉割的男人，青蛇那一剑捅得好！

### 2035 有用 游牧人·芳汀 看过 2010-04-24 22:53:11

张国荣当年若愿意出演许仙的话此片会更美，但曼玉和祖贤姐姐已足够妖冶天仙，赵文卓的法海也更是傲世独立，吴兴国的许仙——猥琐男一个。全片的音乐美不胜收，飘飘欲仙，欲仙欲死，配乐和画面都极为出色。

### 4361 有用 Ridden 看过 2007-08-25 03:16:07

如果有六颗心我就打六星，如果有十颗星我就打十星，别问我为什么！

### 1275 有用 文泽尔 看过 2007-09-26 20:42:50

徐老怪拍的最美的一部片子，连法海都是赵文卓，有这样的白蛇传么..

> 更多短评 94315条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 青蛇的影评 · · · · · · ( 全部 1508 条 )

热门 / 最新 / 好友
Mira 2014-06-10 18:55:48

## 时隔十余年，才懂得小青和法海到底发生过什么

这篇影评可能有剧透

关于《青蛇》这部电影，或许大多数人看的都是央视的删减版，而被删减的部分，却正是这个电影的灵魂和脉络，所以有人说其实《青蛇》是部情色片，我赞同却又不完全赞同，实际上这部电影正是通过神、人、妖三界的七情六欲，来表达人性、伦理与是非，属实是一部很深奥的电影，所以... (展开)
12332 129 547回应 收起
趙小漁 2008-06-07 13:36:06

## 神啊，多賜些痴情的妖精吧！

白素貞說：“小青，我白來世上一趟，一事無成。半生誤我是癡情，你永遠不要重蹈覆轍。切記！” 小青說：“幸好我把他殺了，讓他沒機會遇上另一個新歡。” ——《青蛇》李碧華 春城無處不飛花，寒食東風禦柳斜…… ... (展开)
1913 119 192回应 收起
Kitsune 2010-10-30 17:13:35

## 如果你看懂了，请自动绕道（转）

这篇影评可能有剧透

其实这里很多人看了并不一定真懂。 不是我说大话，如果你看过，并且觉得自己看懂了，就用你的理解回答下面问题， 然后在读我的分析。哈哈，欢迎拍砖。 如果你看完我的分析，觉得颠覆了你本来对影片的理解，请再看一遍电影，对照一下我 讲得对不对。 1.白蛇和青蛇为什么要决裂... (展开)
1719 66 194回应 收起
明珠一颗孙小美 2008-08-19 18:24:21

## 我也渴望爱上一张平淡的脸和一颗善良的心

有段时间cctv6很是中意这部片子，大多在吃饭的时间，一路换频道过去，便死死的把目光留在那两个扭扭扭扭的青衣白衣女子身上。 那时我年方十四五六，剪假小子平头穿平底球鞋，最讨厌这种扭捏作态妖孽横生的小女子姿态，但吞了口水忍了耐心听到那俩小女子扭完说了一句：人类就是... (展开)
1323 169 181回应 收起
麓麓 2005-05-31 10:56:09

## 难得糊涂

这部电影虽是叫《青蛇》，但因为里面法海的戏份过重，因此人们往往对法海似乎更有兴趣，而会略略忽视小青。所以我在此很想谈一下我对小青的理解。 小青是一个只有500年道行的小妖，跟着姐姐来到人世间想要修成正果。但是她自始至终并不知道为什么要成为一个人。 小青很懒惰，... (展开)
579 68 65回应 收起
得一 2011-06-16 10:21:52

## 与有情人做快乐事，未问是劫是缘

这篇影评可能有剧透

[青蛇] 导演 徐克 出品人 吴思远 编剧 徐克/李碧华 监制 徐克 主演 张曼玉/王祖贤/赵文卓/吴兴国/马精武/田丰/刘洵 统筹 陶云/金扬桦 摄影 高照林 剪接 亚积 武术指导 元彬/唐佳 美术指导 雷楚雄/张叔平 服装指导 吴宝玲 音乐 黄沾/雷颂德 出品 思远影业公司 公映日期 1993年4... (展开)
345 4 54回应 收起
缺自行车的鱼 2007-12-06 15:32:48

## 青蛇，看破红尘不是爱，了却当时还伞人.

怀念那时候的电影，妖精来了就是一股青烟，那两条蛇的头饰也不多，王祖贤和张曼玉骨子里就是透着媚气，一个是“朱门旁惨白的余灰，一个是树顶青翠欲滴爽脆刮辣的嫩叶子；一个是白子柜中闷绿的山草药，一个是抬尽了头方见天际皑皑飘飞柔情万缕新雪花。”白蛇和青蛇在一同在西湖... (展开)
363 43 91回应 收起
羽艸 2009-01-24 00:36:58

## 《青蛇》，性的探究

烟雨西湖，水色流音，情真情痴，情之至。 　　 　　《青蛇》，徐克营造了一种无边无际、无法复制的美。绚烂的，旖旎的，江南的，妖异的。张曼玉与王祖贤，两位不世出的绝代佳人，眉梢眼角，无限风情。她们是，但妖媚而不低俗，她们腰肢轻摆，明明白白地卖弄性感,颠倒众生。... (展开)
307 22 32回应 收起
微霄 2009-07-08 09:42:13

## 为了你，我愿做刻舟求剑的傻瓜

知道王祖贤要出家的假消息，第一个想起的不是鬼魅妖娆的小倩，却是《青蛇》里那张如玉面容，飘逸婉转，刚柔并济。 是心中最后一点余热都涣散了，才以“尘缘已了”这样的说辞选择离开么？还是不甘就此沉寂，又是一番热炒回炉，想要上个头条呢？ 我以为就算失望，... (展开)
192 14 73回应 收起

> 更多影评 1508篇

添加新讨论

## 讨论区 · · · · · ·

突然觉得自己爱情观和白蛇很像 | 来自头上有问号 | 3 回应 | 2022-11-21 00:01:10
如果再拍一次青蛇，你心中的人选是谁？ | 来自yes | 81 回应 | 2022-11-16 12:39:20
4k修复啥时候全面公映啊 | 来自vinc |  | 2022-11-14 18:13:33
小青为什么要对许仙说你出卖了我们？ | 来自钧台之享 | 42 回应 | 2022-11-10 01:04:48
只有一个问题 | 来自epiphany | 3 回应 | 2022-11-10 01:00:53

> 去这部影片的讨论区（全部253条）

## 关于《青蛇》的问题 · · · · · · ( 全部18个 )

- 为什么许仙死的时候身上有两把刀？ 10人回答
- 为什么都说许仙懦弱？ 12人回答

> 全部18个问题

## 在哪儿看这部电影 · · · · · ·

- 爱奇艺视频 VIP免费观看
- 优酷视频 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 深情即是一桩悲剧，必得以死来句读。 (眠去)
- 文艺女王必修课「华语篇」 (不良生)
- 179部经典港片 (德拉库拉拉)
- 独立女性必看电影 (aristos)

## 谁在看这部电影 · · · · · ·

- 豆友O4WfE_FJiI
  4分钟前 看过
- 左子骏
  6分钟前 想看
- ヒグレ
  6分钟前 想看

798295人看过 / 119449人想看

订阅青蛇的评论:
feed: rss 2.0